<?php

namespace Drupal\missyou\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\file\Entity\File;

/**
 * Class MissyouSettings.
 */
class MissyouSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'missyou_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config                    = $this->config('missyou.settings');
    $form['missyou_tab_title'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Tab title'),
      '#description'   => $this->t("Enter the title for the browser tab<br>If empty, default title ('I Miss you !') will be shown"),
      '#maxlength'     => 64,
      '#size'          => 64,
      '#required'      => TRUE,
      '#default_value' => $config->get('missyou_tab_title'),
    ];
    $form['missyou_favicon']   = [
      '#type'              => 'managed_file',
      '#title'             => $this->t('Favicon'),
      '#description'       => $this->t("Upload the image file for the favicon in the browser tab<br>If empty, current website's favicon will be used"),
      '#upload_location'   => 'public://missyou/',
      '#upload_validators' => [
        'file_validate_extensions' => ['gif png jpg jpeg'],
      ],
      '#default_value'     => $config->get('missyou_favicon'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('missyou.settings')
      ->set('missyou_tab_title', $form_state->getValue('missyou_tab_title'))
      ->set('missyou_favicon', $form_state->getValue('missyou_favicon'))
      ->save();

    // Fetch the array of the file stored temporarily in database.
    $favicon = $form_state->getValue('missyou_favicon');

    if (!empty($favicon)) {
      // Load the object of the file by it's fid.
      $file = File::load($favicon[0]);

      // Set the status flag permanent of the file object.
      $file->setPermanent();

      // Save the file in database.
      $file->save();
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'missyou.settings',
    ];
  }

}
